# component-registry-bindings
A client library for accessing Component Registry API

## Installation

```
pip install component_registry_bindings
```

## For more details read [tutorial](TUTORIAL.md)

## For development details read [developer guide](DEVELOP.md)
